DetectorFactory

Trait DetectorFactory 

pub trait DetectorFactory: Send {
    // Required methods
    fn name(&self) -> String;
    fn create(&self, n_dims: usize) -> Box<dyn Detector>;
}
Factory for creating fresh detector instances with a specific dimensionality.

Required Methods

fn name(&self) -> String

Returns the display name of this detector.

fn create(&self, n_dims: usize) -> Box<dyn Detector>

Creates a new detector instance configured for the given dimensionality.

Implementors