pub trait DetectorFactory: Send { // Required methods fn name(&self) -> String; fn create(&self, n_dims: usize) -> Box<dyn Detector>; }
Factory for creating fresh detector instances with a specific dimensionality.
Returns the display name of this detector.
Creates a new detector instance configured for the given dimensionality.